<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>AppendDialog</name>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="432"/>
        <source>Add files to the current archive</source>
        <translation>Adicionar arquivos ao arquivo atual</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="437"/>
        <source>Use password</source>
        <translation>Usar senha</translation>
    </message>
</context>
<context>
    <name>CalculateSizeThread</name>
    <message>
        <location filename="../src/source/common/calculatesizethread.cpp" line="68"/>
        <location filename="../src/source/common/calculatesizethread.cpp" line="136"/>
        <source>The original file of %1 does not exist, please check and try again</source>
        <translation>O arquivo original de %1 não existe; verifique e tente novamente</translation>
    </message>
    <message>
        <location filename="../src/source/common/calculatesizethread.cpp" line="70"/>
        <location filename="../src/source/common/calculatesizethread.cpp" line="138"/>
        <source>%1 does not exist on the disk, please check and try again</source>
        <translation>%1 não existe no disco; verifique e tente novamente</translation>
    </message>
    <message>
        <location filename="../src/source/common/calculatesizethread.cpp" line="79"/>
        <location filename="../src/source/common/calculatesizethread.cpp" line="147"/>
        <source>You do not have permission to compress %1</source>
        <translation>Você não tem permissão para comprimir %1</translation>
    </message>
</context>
<context>
    <name>CommentProgressDialog</name>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="234"/>
        <source>Updating the comment...</source>
        <translation>Atualizando o comentário...</translation>
    </message>
</context>
<context>
    <name>CompressPage</name>
    <message>
        <location filename="../src/source/page/compresspage.cpp" line="76"/>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresspage.cpp" line="117"/>
        <source>Please add files</source>
        <translation>Adicione os arquivos</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresspage.cpp" line="117"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>CompressSettingPage</name>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="143"/>
        <location filename="../src/source/page/compresssettingpage.cpp" line="226"/>
        <source>New Archive</source>
        <translation>Novo Arquivo</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="204"/>
        <source>Advanced Options</source>
        <translation>Opções Avançadas</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="208"/>
        <source>Compression method</source>
        <translation>Método de compressão</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="211"/>
        <source>Encrypt the archive</source>
        <translation>Criptografar o arquivo</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="213"/>
        <source>CPU threads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="215"/>
        <source>Encrypt the file list too</source>
        <translation>Criptografar também a lista de arquivos</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="217"/>
        <source>Split to volumes</source>
        <translation>Dividir em volumes</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="219"/>
        <source>Comment</source>
        <translation>Comentário</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="221"/>
        <source>Compress</source>
        <comment>button</comment>
        <translation>Comprimir</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Store</source>
        <translation>Loja</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Fastest</source>
        <translation>Mais rápido</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Fast</source>
        <translation>Rápido</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Good</source>
        <translation>Bom</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Best</source>
        <translation>Melhor</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="247"/>
        <source>Single thread</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="247"/>
        <source>2 threads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="247"/>
        <source>4 threads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="247"/>
        <source>8 threads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="257"/>
        <source>Support zip, 7z type only</source>
        <translation>Suporta apenas .zip e .7z</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="260"/>
        <source>Support 7z type only</source>
        <translation>Suporta apenas .7z</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="272"/>
        <source>Enter up to %1 characters</source>
        <translation>Insira até %1 caracteres</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="293"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="294"/>
        <source>Save to</source>
        <translation>Salvar em</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="483"/>
        <source>Invalid file name</source>
        <translation>Nome de arquivo inválido</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="489"/>
        <source>Please enter the path</source>
        <translation>Insira o caminho</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="494"/>
        <source>The path does not exist, please retry</source>
        <translation>O caminho não existe; tente novamente</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="499"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>Você não tem permissão para salvar os arquivos aqui; altere e tente novamente</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="507"/>
        <source>Too many volumes, please change and retry</source>
        <translation>Há muitos volumes; altere e tente novamente</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="516"/>
        <location filename="../src/source/page/compresssettingpage.cpp" line="544"/>
        <source>%1 does not exist on the disk, please check and try again</source>
        <translation>%1 não existe no disco; verifique e tente novamente</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="522"/>
        <location filename="../src/source/page/compresssettingpage.cpp" line="551"/>
        <source>You do not have permission to compress %1</source>
        <translation>Você não tem permissão para comprimir %1</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="542"/>
        <source>The original file of %1 does not exist, please check and try again</source>
        <translation>O arquivo original de %1 não existe; verifique e tente novamente</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="577"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="783"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="783"/>
        <source>Replace</source>
        <comment>button</comment>
        <translation>Substituir</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="691"/>
        <source>Total size: %1</source>
        <translation>Tamanho total: %1</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="711"/>
        <source>The name is the same as that of the compressed archive, please use another one</source>
        <translation>O nome é o mesmo que o do arquivo comprimido; use outro</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="719"/>
        <source>The password for ZIP volumes cannot be in Chinese</source>
        <translation>A senha para arquivos ZIP não pode estar em Chinês</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="783"/>
        <source>Another file with the same name already exists, replace it?</source>
        <translation>Já existe um outro arquivo com o mesmo nome. Substituí-lo?</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="823"/>
        <source>Only Chinese and English characters and some symbols are supported</source>
        <translation>Apenas caracteres chineses / ingleses e alguns símbolos são suportados</translation>
    </message>
</context>
<context>
    <name>CompressView</name>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="284"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="298"/>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="301"/>
        <source>Open with</source>
        <translation>Abrir com</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="305"/>
        <location filename="../src/source/tree/compressview.cpp" line="407"/>
        <source>Select default program</source>
        <translation>Selecionar o aplicativo padrão</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="348"/>
        <source>It will permanently delete the file(s). Are you sure you want to continue?</source>
        <translation>Isso excluirá permanentemente o(s) arquivo(s). Continuar?</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="348"/>
        <location filename="../src/source/tree/compressview.cpp" line="381"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="348"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="382"/>
        <source>Add</source>
        <comment>button</comment>
        <translation>Adicionar</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="380"/>
        <source>Do you want to add the archive to the list or open it in new window?</source>
        <translation>Adicionar o arquivo à lista ou abri-lo em uma nova janela?</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="383"/>
        <source>Open in new window</source>
        <translation>Abrir em nova janela</translation>
    </message>
</context>
<context>
    <name>ConvertDialog</name>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="306"/>
        <source>Changes to archives in this file type are not supported. Please convert the archive format to save the changes.</source>
        <translation>As alterações nos arquivos deste formato não são suportadas. Para salvar as alterações, converta o arquivo para outro formato.</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="314"/>
        <source>Convert the format to:</source>
        <translation>Converter o formato para:</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="338"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="339"/>
        <source>Convert</source>
        <comment>button</comment>
        <translation>Converter</translation>
    </message>
</context>
<context>
    <name>DataModel</name>
    <message>
        <location filename="../src/source/tree/datamodel.cpp" line="70"/>
        <source>item(s)</source>
        <translation>item(ns)</translation>
    </message>
</context>
<context>
    <name>FailurePage</name>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="87"/>
        <source>Extraction failed</source>
        <comment>解压失败</comment>
        <translation>A extração falhou</translation>
    </message>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="100"/>
        <source>Damaged file, unable to extract</source>
        <translation>Arquivo danificado, impossível extrair</translation>
    </message>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="105"/>
        <source>Retry</source>
        <comment>button</comment>
        <translation>Tentar novamente</translation>
    </message>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="108"/>
        <source>Back</source>
        <translation>Voltar</translation>
    </message>
</context>
<context>
    <name>HomePage</name>
    <message>
        <location filename="../src/source/page/homepage.cpp" line="56"/>
        <source>Drag file or folder here</source>
        <translation>Arraste o Arquivo ou Pasta até aqui</translation>
    </message>
    <message>
        <location filename="../src/source/page/homepage.cpp" line="58"/>
        <source>Select File</source>
        <translation>Selecionar Arquivo</translation>
    </message>
</context>
<context>
    <name>LoadCorruptQuery</name>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="525"/>
        <source>The archive is damaged</source>
        <translation>O arquivo está danificado</translation>
    </message>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="528"/>
        <source>Open as read-only</source>
        <translation>Abrir como somente leitura</translation>
    </message>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="529"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>LoadingPage</name>
    <message>
        <location filename="../src/source/page/loadingpage.cpp" line="65"/>
        <source>Loading, please wait...</source>
        <translation>Carregando, aguarde...</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../src/main.cpp" line="60"/>
        <location filename="../src/main.cpp" line="61"/>
        <source>Archive Manager</source>
        <translation>Gerenciador de Compressão</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="62"/>
        <source>Archive Manager is a fast and lightweight application for creating and extracting archives.</source>
        <translation>O Gerenciador de Compressão é um aplicativo rápido e leve para comprimir e extrair arquivos.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="172"/>
        <location filename="../src/source/mainwindow.cpp" line="191"/>
        <location filename="../src/source/mainwindow.cpp" line="440"/>
        <source>Open file</source>
        <translation>Abrir arquivo</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="173"/>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="294"/>
        <location filename="../src/source/mainwindow.cpp" line="304"/>
        <source>Create New Archive</source>
        <translation>Criar Novo Arquivo</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="345"/>
        <source>Converting</source>
        <translation>Convertendo</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="352"/>
        <source>Updating comments</source>
        <translation>Atualizando comentários</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="523"/>
        <location filename="../src/source/mainwindow.cpp" line="2068"/>
        <location filename="../src/source/mainwindow.cpp" line="2090"/>
        <location filename="../src/source/mainwindow.cpp" line="2115"/>
        <source>Plugin error</source>
        <translation>Erro de plugin</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1302"/>
        <source>Adding successful</source>
        <translation>Adição bem-sucedida</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1334"/>
        <location filename="../src/source/mainwindow.cpp" line="2139"/>
        <source>No data in it</source>
        <translation>Não há dados</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1522"/>
        <source>Adding canceled</source>
        <translation>Adição cancelada</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1620"/>
        <source>Adding failed</source>
        <translation>A adição falhou</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1673"/>
        <source>Extraction failed: the file name is too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1700"/>
        <location filename="../src/source/mainwindow.cpp" line="2135"/>
        <source>Failed to create &quot;%1&quot;</source>
        <translation>Falha ao criar &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1822"/>
        <source>Open failed: the file name is too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2041"/>
        <source>Compression successful</source>
        <translation>Compressão bem-sucedida</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2047"/>
        <source>The file name is too long, so the first 60 characters have been intercepted as the file name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2076"/>
        <location filename="../src/source/mainwindow.cpp" line="2143"/>
        <source>Insufficient disk space</source>
        <translation>Espaço insuficiente em disco</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2102"/>
        <location filename="../src/source/mainwindow.cpp" line="2123"/>
        <source>Some volumes are missing</source>
        <translation>Alguns volumes estão ausentes</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2127"/>
        <source>Wrong password, please retry</source>
        <translation>Senha incorreta; tente novamente</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2131"/>
        <location filename="../src/source/mainwindow.cpp" line="2155"/>
        <source>The file name is too long. Keep the name within 60 characters please.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2152"/>
        <source>Conversion failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2290"/>
        <source>Select file</source>
        <translation>Selecionar arquivo</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3102"/>
        <source>Enter up to %1 characters</source>
        <translation>Insira até %1 caracteres</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="196"/>
        <location filename="../src/source/mainwindow.cpp" line="2978"/>
        <source>File info</source>
        <translation>Informações do arquivo</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1411"/>
        <source>Do you want to delete the archive?</source>
        <translation>Excluir arquivo?</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="553"/>
        <source>%1 was changed on the disk, please import it again.</source>
        <translation>%1 foi alterado no disco; importe-o novamente.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="73"/>
        <source>Archive Manager</source>
        <translation>Gerenciador de Compressão</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="129"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>Você não tem permissão para salvar os arquivos aqui; altere e tente novamente</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="317"/>
        <source>Adding files to %1</source>
        <translation>Adicionando os arquivos a %1</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="324"/>
        <source>Compressing</source>
        <translation>Comprimindo</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="331"/>
        <source>Extracting</source>
        <translation>Extraindo</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="338"/>
        <source>Deleting</source>
        <translation>Excluindo</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="443"/>
        <source>Back</source>
        <translation>Voltar</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="513"/>
        <location filename="../src/source/mainwindow.cpp" line="2802"/>
        <source>Loading, please wait...</source>
        <translation>Carregando, aguarde...</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="586"/>
        <source>Are you sure you want to stop the ongoing task?</source>
        <translation>Interromper a tarefa em andamento?</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1308"/>
        <location filename="../src/source/mainwindow.cpp" line="1434"/>
        <source>Updating, please wait...</source>
        <translation>Atualizando, aguarde...</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1695"/>
        <source>File name too long</source>
        <translation>O nome do arquivo é muito longo</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2072"/>
        <source>Failed to create file</source>
        <translation>Falha ao criar arquivo</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2065"/>
        <source>Compression failed</source>
        <translation>A compressão falhou</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2400"/>
        <source>Replace</source>
        <comment>button</comment>
        <translation>Substituir</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2464"/>
        <source>Find directory</source>
        <translation>Pesquisar diretório</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2087"/>
        <source>Open failed</source>
        <translation>A abertura falhou</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1616"/>
        <location filename="../src/source/mainwindow.cpp" line="1690"/>
        <location filename="../src/source/mainwindow.cpp" line="1765"/>
        <location filename="../src/source/mainwindow.cpp" line="1820"/>
        <location filename="../src/source/mainwindow.cpp" line="2098"/>
        <source>Wrong password</source>
        <translation>Senha incorreta</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="626"/>
        <location filename="../src/source/mainwindow.cpp" line="659"/>
        <source>The file format is not supported by Archive Manager</source>
        <translation>O formato do arquivo não é compatível com o Gerenciador de Compressão</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="129"/>
        <location filename="../src/source/mainwindow.cpp" line="461"/>
        <location filename="../src/source/mainwindow.cpp" line="523"/>
        <location filename="../src/source/mainwindow.cpp" line="556"/>
        <location filename="../src/source/mainwindow.cpp" line="611"/>
        <location filename="../src/source/mainwindow.cpp" line="617"/>
        <location filename="../src/source/mainwindow.cpp" line="626"/>
        <location filename="../src/source/mainwindow.cpp" line="666"/>
        <location filename="../src/source/mainwindow.cpp" line="1334"/>
        <location filename="../src/source/mainwindow.cpp" line="2271"/>
        <location filename="../src/source/mainwindow.cpp" line="2558"/>
        <location filename="../src/source/mainwindow.cpp" line="2722"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="461"/>
        <location filename="../src/source/mainwindow.cpp" line="617"/>
        <source>You do not have permission to load %1</source>
        <translation>Você não tem permissão para carregar %1</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="586"/>
        <location filename="../src/source/mainwindow.cpp" line="1411"/>
        <location filename="../src/source/mainwindow.cpp" line="2400"/>
        <location filename="../src/source/mainwindow.cpp" line="2824"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="586"/>
        <location filename="../src/source/mainwindow.cpp" line="1411"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="611"/>
        <source>No such file or directory</source>
        <translation>Nenhum arquivo ou diretório</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1350"/>
        <source>Extraction successful</source>
        <comment>提取成功</comment>
        <translation>A extração foi bem-sucedida</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1543"/>
        <source>Extraction canceled</source>
        <comment>取消提取</comment>
        <translation>A extração foi cancelada</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1685"/>
        <location filename="../src/source/mainwindow.cpp" line="1760"/>
        <location filename="../src/source/mainwindow.cpp" line="2094"/>
        <location filename="../src/source/mainwindow.cpp" line="2119"/>
        <source>The archive is damaged</source>
        <translation>O arquivo está danificado</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2045"/>
        <source>Extraction successful</source>
        <comment>解压成功</comment>
        <translation>A extração foi bem-sucedida</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2051"/>
        <source>Conversion successful</source>
        <translation>Conversão bem-sucedida</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2112"/>
        <source>Extraction failed</source>
        <comment>解压失败</comment>
        <translation>A extração falhou</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2282"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2286"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2294"/>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2302"/>
        <source>Display shortcuts</source>
        <translation>Exibir atalhos</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2314"/>
        <source>Shortcuts</source>
        <translation>Atalhos</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2392"/>
        <source>The name is the same as that of the compressed archive, please use another one</source>
        <translation>O nome é o mesmo que o do arquivo comprimido; use outro</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2400"/>
        <source>Another file with the same name already exists, replace it?</source>
        <translation>Já existe um outro arquivo com o mesmo nome. Substituí-lo?</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2543"/>
        <source>You cannot add the archive to itself</source>
        <translation>Não é possível adicionar o arquivo a si mesmo</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2558"/>
        <source>You cannot add files to archives in this file type</source>
        <translation>Você não pode adicionar os arquivos a este tipo de arquivo</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2824"/>
        <source>Update</source>
        <comment>button</comment>
        <translation>Atualizar</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3002"/>
        <source>Basic info</source>
        <translation>Informações básicas</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3018"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3019"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3020"/>
        <source>Location</source>
        <translation>Localização</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3021"/>
        <source>Time created</source>
        <translation>Data da criação</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3022"/>
        <source>Time accessed</source>
        <translation>Último acesso</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3023"/>
        <source>Time modified</source>
        <translation>Última modificação</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3033"/>
        <source>Archive</source>
        <translation>Arquivo</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3064"/>
        <source>Comment</source>
        <translation>Comentário</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="656"/>
        <source>Please check the file association type in the settings of Archive Manager</source>
        <translation>Verifique o tipo de associação do arquivo nas configurações do Gerenciador de Arquivos</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2271"/>
        <source>The archive was changed on the disk, please import it again.</source>
        <translation>O arquivo foi alterado no disco; importe-o novamente.</translation>
    </message>
</context>
<context>
    <name>MimeTypeDisplayManager</name>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="46"/>
        <source>Directory</source>
        <translation>Diretório</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="47"/>
        <source>Application</source>
        <translation>Aplicativo</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="48"/>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="49"/>
        <source>Audio</source>
        <translation>Áudio</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="50"/>
        <source>Image</source>
        <translation>Imagem</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="51"/>
        <source>Archive</source>
        <translation>Arquivo</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="53"/>
        <source>Executable</source>
        <translation>Executável</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="52"/>
        <source>Document</source>
        <translation>Documento</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="54"/>
        <source>Backup file</source>
        <translation>Arquivo de backup</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="55"/>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
</context>
<context>
    <name>OpenWithDialog</name>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="280"/>
        <source>Open with</source>
        <translation>Abrir com</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="300"/>
        <source>Add other programs</source>
        <translation>Adicionar outro aplicativo</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="301"/>
        <source>Set as default</source>
        <translation>Definir como padrão</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="303"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="304"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="308"/>
        <source>Recommended Applications</source>
        <translation>Aplicativos Recomendados</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="310"/>
        <source>Other Applications</source>
        <translation>Outros Aplicativos</translation>
    </message>
</context>
<context>
    <name>PasswordNeededQuery</name>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="394"/>
        <source>Encrypted file, please enter the password</source>
        <translation>Arquivo criptografado; insira a senha</translation>
    </message>
</context>
<context>
    <name>PreviousLabel</name>
    <message>
        <location filename="../src/source/tree/treeheaderview.cpp" line="52"/>
        <source>Current path:</source>
        <translation>Caminho atual:</translation>
    </message>
    <message>
        <location filename="../src/source/tree/treeheaderview.cpp" line="60"/>
        <source>Back to: %1</source>
        <translation>Voltar para: %1</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="52"/>
        <source>%1 task(s) in progress</source>
        <translation>%1 tarefa(s) em andamento</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="59"/>
        <location filename="../src/source/dialog/progressdialog.cpp" line="102"/>
        <source>Task</source>
        <translation>Tarefa</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="65"/>
        <location filename="../src/source/dialog/progressdialog.cpp" line="113"/>
        <source>Extracting</source>
        <translation>Extraindo</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="192"/>
        <source>Are you sure you want to stop the extraction?</source>
        <translation>Interromper a extração?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="194"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="194"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>ProgressPage</name>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="52"/>
        <location filename="../src/source/page/progresspage.cpp" line="314"/>
        <location filename="../src/source/page/progresspage.cpp" line="317"/>
        <location filename="../src/source/page/progresspage.cpp" line="320"/>
        <source>Speed</source>
        <comment>compress</comment>
        <translation>Velocidade</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="52"/>
        <location filename="../src/source/page/progresspage.cpp" line="54"/>
        <location filename="../src/source/page/progresspage.cpp" line="56"/>
        <location filename="../src/source/page/progresspage.cpp" line="60"/>
        <location filename="../src/source/page/progresspage.cpp" line="63"/>
        <location filename="../src/source/page/progresspage.cpp" line="149"/>
        <source>Calculating...</source>
        <translation>Calculando...</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="54"/>
        <location filename="../src/source/page/progresspage.cpp" line="324"/>
        <location filename="../src/source/page/progresspage.cpp" line="326"/>
        <source>Speed</source>
        <comment>delete</comment>
        <translation>Velocidade</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="56"/>
        <location filename="../src/source/page/progresspage.cpp" line="338"/>
        <location filename="../src/source/page/progresspage.cpp" line="340"/>
        <location filename="../src/source/page/progresspage.cpp" line="342"/>
        <source>Speed</source>
        <comment>convert</comment>
        <translation>Velocidade</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="60"/>
        <location filename="../src/source/page/progresspage.cpp" line="330"/>
        <location filename="../src/source/page/progresspage.cpp" line="332"/>
        <location filename="../src/source/page/progresspage.cpp" line="334"/>
        <source>Speed</source>
        <comment>uncompress</comment>
        <translation>Velocidade</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="63"/>
        <location filename="../src/source/page/progresspage.cpp" line="310"/>
        <source>Time left</source>
        <translation>Tempo restante</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="122"/>
        <source>Compressing</source>
        <translation>Comprimindo</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="124"/>
        <source>Deleting</source>
        <translation>Excluindo</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="126"/>
        <source>Converting</source>
        <translation>Convertendo</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="128"/>
        <location filename="../src/source/page/progresspage.cpp" line="147"/>
        <source>Updating the comment...</source>
        <translation>Atualizando o comentário...</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="130"/>
        <source>Extracting</source>
        <translation>Extraindo</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="141"/>
        <location filename="../src/source/page/progresspage.cpp" line="178"/>
        <location filename="../src/source/page/progresspage.cpp" line="358"/>
        <source>Pause</source>
        <comment>button</comment>
        <translation>Pausar</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="177"/>
        <location filename="../src/source/page/progresspage.cpp" line="387"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="354"/>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Continuar</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="387"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="376"/>
        <source>Are you sure you want to stop the decompression?</source>
        <translation>Interromper a descompressão?</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="378"/>
        <source>Are you sure you want to stop the deletion?</source>
        <translation>Interromper a exclusão?</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="374"/>
        <location filename="../src/source/page/progresspage.cpp" line="380"/>
        <source>Are you sure you want to stop the compression?</source>
        <translation>Interromper a compressão?</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="382"/>
        <source>Are you sure you want to stop the conversion?</source>
        <translation>Interromper a conversão?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Time modified</source>
        <translation>Última modificação</translation>
    </message>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2821"/>
        <source>%1 changed. Do you want to save changes to the archive?</source>
        <translation>%1 alterou. Salvar as alterações no arquivo?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="26"/>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="27"/>
        <source>Extraction</source>
        <translation>Extração</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="28"/>
        <source>Auto create a folder for multiple extracted files</source>
        <translation>Criar automaticamente uma pasta para os múltiplos arquivos extraídos</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="29"/>
        <source>Show extracted files when completed</source>
        <translation>Exibir os arquivos extraídos ao concluir</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="30"/>
        <source>File Management</source>
        <translation>Gerenciamento de Arquivos</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="31"/>
        <source>Delete files after compression</source>
        <translation>Excluir os arquivos após compressão</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="32"/>
        <source>Files Associated</source>
        <translation>Arquivos Associados</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="33"/>
        <source>File Type</source>
        <translation>Tipo de Arquivo</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="202"/>
        <location filename="../src/source/dialog/popupdialog.cpp" line="208"/>
        <location filename="../3rdparty/interface/queries.cpp" line="244"/>
        <source>Skip</source>
        <comment>button</comment>
        <translation>Pular</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="203"/>
        <source>Merge</source>
        <comment>button</comment>
        <translation>Mesclar</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="206"/>
        <location filename="../3rdparty/interface/queries.cpp" line="221"/>
        <source>Another file with the same name already exists, replace it?</source>
        <translation>Já existe um outro arquivo com o mesmo nome. Substituí-lo?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="209"/>
        <location filename="../3rdparty/interface/queries.cpp" line="245"/>
        <source>Replace</source>
        <comment>button</comment>
        <translation>Substituir</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="477"/>
        <location filename="../3rdparty/interface/queries.cpp" line="405"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="478"/>
        <location filename="../3rdparty/interface/queries.cpp" line="406"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="200"/>
        <source>Another folder with the same name already exists, replace it?</source>
        <translation>Já existe outra pasta com o mesmo nome; substituí-la?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="212"/>
        <location filename="../3rdparty/interface/queries.cpp" line="226"/>
        <source>Apply to all</source>
        <translation>Aplicar a todos</translation>
    </message>
</context>
<context>
    <name>SettingDialog</name>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="166"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="195"/>
        <source>Current directory</source>
        <translation>Diretório atual</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="125"/>
        <source>Clear All</source>
        <translation>Limpar Tudo</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="124"/>
        <source>Select All</source>
        <comment>button</comment>
        <translation>Selecionar tudo</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="126"/>
        <source>Recommended</source>
        <translation>Recomendado</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="160"/>
        <source>Extract archives to</source>
        <translation>Extrair arquivos para</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="166"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="205"/>
        <source>Other directory</source>
        <translation>Outro diretório</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="166"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="200"/>
        <source>Desktop</source>
        <translation>Área de Trabalho</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="272"/>
        <source>Delete archives after extraction</source>
        <translation>Excluir os arquivos após a extração</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="278"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="299"/>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="278"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="302"/>
        <source>Ask for confirmation</source>
        <translation>Solicitar confirmação</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="278"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="305"/>
        <source>Always</source>
        <translation>Sempre</translation>
    </message>
</context>
<context>
    <name>SuccessPage</name>
    <message>
        <location filename="../src/source/page/successpage.cpp" line="79"/>
        <source>Compression successful</source>
        <translation>Compressão bem-sucedida</translation>
    </message>
    <message>
        <location filename="../src/source/page/successpage.cpp" line="89"/>
        <source>View</source>
        <translation>Visualizar</translation>
    </message>
    <message>
        <location filename="../src/source/page/successpage.cpp" line="92"/>
        <source>Back</source>
        <translation>Voltar</translation>
    </message>
</context>
<context>
    <name>UnCompressPage</name>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="75"/>
        <location filename="../src/source/page/uncompresspage.cpp" line="87"/>
        <location filename="../src/source/page/uncompresspage.cpp" line="116"/>
        <source>Extract to:</source>
        <translation>Extrair para:</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="117"/>
        <source>Extract</source>
        <comment>button</comment>
        <translation>Extrair</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="191"/>
        <source>The default extraction path does not exist, please retry</source>
        <translation>O caminho de extração padrão não existe; tente novamente</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="193"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>Não há permissão para salvar arquivos aqui; altere e tente novamente</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="197"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="211"/>
        <source>Find directory</source>
        <translation>Encontrar diretório</translation>
    </message>
</context>
<context>
    <name>UnCompressView</name>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="392"/>
        <source>You cannot add the archive to itself</source>
        <translation>Não é possível adicionar o arquivo a si mesmo</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="392"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="618"/>
        <source>Extract</source>
        <comment>提取</comment>
        <translation>Extrair</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="620"/>
        <source>Extract to current directory</source>
        <translation>Extrair no diretório atual</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="622"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="625"/>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="632"/>
        <source>Open with</source>
        <translation>Abrir com</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="636"/>
        <location filename="../src/source/tree/uncompressview.cpp" line="737"/>
        <source>Select default program</source>
        <translation>Selecionar o aplicativo padrão</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="687"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="687"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="687"/>
        <source>Do you want to delete the selected file(s)?</source>
        <translation>Excluir o(s) arquivo(s) selecionado(s)?</translation>
    </message>
</context>
</TS>
